@@ -105,3 +105,16 @@ def km(km):
     dm = km/10000
     m = km/1000
     return "Centimeter:", str(sm), "Decimetr:", str(dm), "Meter:", str(m)
+
+#speed, time, distance traveled
+def speed(s, t):
+    v = s / t
+    return v
+
+def time(s, v):
+    t = s / v
+    return t
+
+def distance(v, t):
+    s = v * t
+    return s
\ No newline at end of file
